@@ -1,7 +1,7 @@
 # Module: FeatureEngineering
 # Author: Adrian Antico <adrianantico@gmail.com>
 # License: MIT
-# Release: retrofit 0.0.5
+# Release: retrofit 0.0.8
 # Last modified : 2021-08-31
 
 def FE0_AutoLags(data = None, ArgsList=None, LagColumnNames = None, DateColumnName = None, ByVariables = None, LagPeriods = 1, ImputeValue = -1, Sort = True, Processing='datatable', InputFrame='datatable', OutputFrame='datatable'):
@@ -845,7 +845,7 @@ def FE1_DummyVariables(data=None, ArgsList=None, CategoricalColumnNames=None, Pr
     InputFrame:             'datatable', 'polars', or 'pandas' If you input Frame is 'pandas', it will be converted to a datatable Frame for generating the new columns
     OutputFrame:            'datatable', 'polars', or 'pandas' If you want the output Frame to be pandas change value to 'pandas'
     
-    # Example
+    # Example: datatable
     import datatable as dt
     import retrofit
     from retrofit import FeatureEngineering as fe
@@ -854,6 +854,15 @@ def FE1_DummyVariables(data=None, ArgsList=None, CategoricalColumnNames=None, Pr
     data = Output['data']
     ArgsList = Output['ArgsList']
     
+    # Example: polars
+    import retrofit
+    from retrofit import FeatureEngineering as fe
+    import polars as pl
+    data = pl.read_csv("C:/Users/Bizon/Documents/GitHub/BenchmarkData.csv")
+    Output = fe.FE1_DummyVariables(data=data, ArgsList=None, CategoricalColumnNames=['MarketingSegments','MarketingSegments2'], Processing='polars', InputFrame='polars', OutputFrame='polars')
+    data = Output['data']
+    ArgsList = Output['ArgsList']
+    
     # QA
     ArgsList=None
     CategoricalColumnNames=['MarketingSegments','MarketingSegments2']
@@ -861,6 +870,9 @@ def FE1_DummyVariables(data=None, ArgsList=None, CategoricalColumnNames=None, Pr
     InputFrame='datatable'
     OutputFrame='datatable'
     
+    Processing='polars'
+    InputFrame='polars'
+    OutputFrame='polars'
     """
     # ArgsList Collection
     if not ArgsList is None:
@@ -869,12 +881,12 @@ def FE1_DummyVariables(data=None, ArgsList=None, CategoricalColumnNames=None, Pr
       ArgsList = dict(CategoricalColumnNames=CategoricalColumnNames)
     
     # Import datatable methods
-    if Processing.lower == 'datatable' or OutputFrame.lower == 'datatable' or InputFrame.lower == 'datatable':
+    if Processing.lower() == 'datatable' or OutputFrame.lower() == 'datatable' or InputFrame.lower() == 'datatable':
       import datatable as dt
       from datatable import split_into_nhot, str
 
     # Import polars methods
-    if Processing.lower == 'polars' or OutputFrame.lower == 'polars' or InputFrame.lower == 'polars':
+    if Processing.lower() == 'polars' or OutputFrame.lower() == 'polars' or InputFrame.lower() == 'polars':
       import polars as pl
       from polars import col
       from polars.lazy import col
@@ -884,29 +896,36 @@ def FE1_DummyVariables(data=None, ArgsList=None, CategoricalColumnNames=None, Pr
       CategoricalColumnNames = [CategoricalColumnNames]
 
     # Convert to datatable
-    if InputFrame.lower == 'pandas' and Processing.lower == 'datatable': 
+    if InputFrame.lower() == 'pandas' and Processing.lower() == 'datatable': 
       data = dt.Frame(data)
-    elif InputFrame.lower == 'pandas' and Processing.lower == 'polars':
+    elif InputFrame.lower() == 'pandas' and Processing.lower() == 'polars':
       data = pl.from_pandas(data)
 
     # Create dummies
-    data_new = data.copy()
-    for column in CategoricalColumnNames:
-      df_ohe = str.split_into_nhot(data_new[column])
-      df_ohe.names = [f'{column}_{col}' for col in df_ohe.names]
-      data_new.cbind(df_ohe)
+    if Processing.lower() == 'datatable':
+      data_new = data.copy()
+      for column in CategoricalColumnNames:
+        df_ohe = dt.str.split_into_nhot(data_new[column])
+        df_ohe.names = [f'{column}_{col}' for col in df_ohe.names]
+        data_new.cbind(df_ohe)
+    elif Processing.lower() == 'polars':
+      for column in CategoricalColumnNames:
+        data = data.hstack(pl.get_dummies(data[column]))
 
     # Convert Frame
-    if OutputFrame.lower == 'pandas' and Processing.lower == 'datatable': 
+    if OutputFrame.lower() == 'pandas' and Processing.lower() == 'datatable': 
       data = data.to_pandas()
-    elif OutputFrame.lower == 'pandas' and Processing.lower == 'polars':
+    elif OutputFrame.lower() == 'pandas' and Processing.lower() == 'polars':
       data = data.to_pandas()
-    elif OutputFrame.lower == 'datatable' and Processing.lower == 'polars':
+    elif OutputFrame.lower() == 'datatable' and Processing.lower() == 'polars':
       data = data.to_pandas()
       data = dt.Frame(data)
 
     # Return data
-    return dict(data = data_new, ArgsList = ArgsList)
+    if Processing.lower() == 'datatable':
+      return dict(data = data_new, ArgsList = ArgsList)
+    elif Processing.lower() == 'polars':
+      return dict(data = data, ArgsList = ArgsList)
 
 def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, PartitionType='random', Ratios=None, ByVariables=None, Processing='datatable', InputFrame='datatable', OutputFrame='datatable'):
     
@@ -991,27 +1010,27 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
     from retrofit import utils as u
 
     # Import datatable methods
-    if Processing.lower == 'datatable' or OutputFrame.lower == 'datatable' or InputFrame.lower == 'datatable':
+    if Processing.lower() == 'datatable' or OutputFrame.lower() == 'datatable' or InputFrame.lower() == 'datatable':
       import datatable as dt
       from datatable import f, by, sort
 
     # Import polars methods
-    if Processing.lower == 'polars' or OutputFrame.lower == 'polars' or InputFrame.lower == 'polars':
+    if Processing.lower() == 'polars' or OutputFrame.lower() == 'polars' or InputFrame.lower() == 'polars':
       import polars as pl
       from polars import col
       from polars.lazy import col
 
     # Convert to datatable
-    if InputFrame.lower == 'pandas' and Processing.lower == 'datatable':
+    if InputFrame.lower() == 'pandas' and Processing.lower() == 'datatable':
       data = dt.Frame(data)
-    elif InputFrame.lower == 'pandas' and Processing.lower == 'polars':
+    elif InputFrame.lower() == 'pandas' and Processing.lower() == 'polars':
       data = pl.from_pandas(data)
 
     # Accumulate Ratios
     Ratios = u.cumsum(Ratios)
 
     # Random partitioning
-    if PartitionType.lower == 'random':
+    if PartitionType.lower() == 'random':
 
       # Add random number column
       data = data[:, f[:].extend({"ID": np.random.uniform(0,1, size = data.shape[0])})]
@@ -1032,12 +1051,12 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
         TestData = None
 
     # Time base partitioning
-    if PartitionType.lower == 'time':
+    if PartitionType.lower() == 'time':
       
       # Sort data
-      if Sort == True and Processing.lower == 'datatable':
+      if Sort == True and Processing.lower() == 'datatable':
         data = data[:, :, sort(f[DateColumnName], reverse = False)]
-      elif Sort == True and Processing.lower == 'polars':
+      elif Sort == True and Processing.lower() == 'polars':
         data = (data.sort(f[DateColumnName], reverse = False))
 
       # Grab row number boundaries
@@ -1057,12 +1076,12 @@ def FE2_AutoDataParition(data=None, ArgsList=None, DateColumnName=None, Partitio
         TestData = None
 
     # Convert Frame
-    if OutputFrame.lower == 'pandas' and (Processing.lower == 'datatable' or Processing.lower == 'polars'):
+    if OutputFrame.lower() == 'pandas' and (Processing.lower() == 'datatable' or Processing.lower() == 'polars'):
       TrainData = TrainData.to_pandas()
       ValidationData = ValidationData.to_pandas()
       if len(Ratios) == 3:
         TestData = TestData.to_pandas()
-    elif OutputFrame.lower == 'datatable' and Processing.lower == 'polars':
+    elif OutputFrame.lower() == 'datatable' and Processing.lower() == 'polars':
       TrainData = TrainData.to_pandas()
       TrainData = dt.Frame(TrainData)
       ValidationData = ValidationData.to_pandas()
